@@ -17,6 +17,8 @@ class WatchDog():
                 try:
                     connections[database.name].connect()
                     database.change_status(DatabaseStatus.RUNNING.value)
+                    database.is_up.set()
                 except database.operational_error:
                     database.change_status(DatabaseStatus.DOWN.value)
+                    database.is_up.clear()
 
